<?php
/**
 * Extends WP Super Cache to allow it to work correctly with Aelia Internationalisation
 * solutions.
 *
 * @author Aelia <support@aelia.co>
 */
class Aelia_Internationalisation_WPSuperCache {
	const VERSION = '1.0.1.160401';

	// @var Aelia_Internationalisation_SuperCache The class instance
	protected static $instance;

	// @var string The cache key that Super Cache should use to retrieve the cached content
	protected $cache_key;

	// @var array A list of the cookies that should be processed to build the cache key
	protected function expected_cookies() {
		return array(
			'aelia_cs_selected_currency',
			'aelia_customer_country',
			'aelia_customer_state',
			'aelia_billing_country',
			'aelia_tax_exempt',
		);
	}

	/**
	 * Returns the cache key to be used by WP Super Cache. The key takes into account
	 * elements such as the selected currency, customer's country, customer's
	 * State/county, and so on.
	 *
	 * @return string
	 */
	protected function get_cache_key() {
		$cache_key = '';
		foreach($this->expected_cookies() as $cookie_name) {
			if(!empty($_COOKIE[$cookie_name])) {
				$cache_key .= $_COOKIE[$cookie_name];
			}
		}
		return $cache_key;
	}

	/**
	 * Class constructor.
	 */
	public function __construct() {
		$this->cache_key = $this->get_cache_key();

		// If one or more cookies are set by the Aelia internationalisation plugins,
		// enable the callback that will set the cache key
		if(!empty($this->cache_key)) {
			add_cacheaction('wp_cache_key', array($this, 'wp_cache_key'), 10, 1);
		}
		else {
			// Debug
			//var_dump("NO COOKIES FOUND. ASSUMING FIRST TIME VISITOR AND DISABLING CACHE");
			if(!defined('DONOTCACHEPAGE')) {
				define('DONOTCACHEPAGE', true);
			}
		}
	}

	/**
	 * Initialises the plugin.
	 */
	public static function init() {
		self::$instance = new self();
	}

	/**
	 * Extends the standard cache key with one that includes additional arguments,
	 * such as customer's currency, country, state, etc.
	 *
	 * @param string $cache_key The original cache key passed by WP Super Cache.
	 * @return string The updated cache key.
	 */
	public function wp_cache_key($cache_key) {
		$cache_key .= (string)$this->cache_key;
		// Debug
		//var_dump("CACHE KEY FOR PAGE: {$cache_key}");
		return $cache_key;
	}
}

$GLOBALS['aelia-internationalisation-wpsupercache'] = Aelia_Internationalisation_WPSuperCache::init();
